.. vim: set fileencoding=utf-8 :
.. author: Manuel Günther <manuel.guenther@idiap.ch>
.. date: Thu Sep 20 11:58:57 CEST 2012

==========
References
==========

.. [Rey00] *D. A. Reynolds, T. F. Quatieri, R. B. Dunn*, **Speaker verification using adapted Gaussian mixture models**. Digital Signal Processing 10 (2000) 19–41.
.. [Vogt08] *R. Vogt, S. Sridharan*, **Explicit modelling of session variability for speaker verification**. Computer Speech & Language 22 (1) (2008) 17–38.
.. [Dehak11] *N. Dehak, P. Kenny, R. Dehak, P. Dumouchel, P. Ouellet*, **Front-end factor analysis for speaker verification**. IEEE Trans. on Audio, Speech, and Language Processing 19 (2011) 788–798.
